NeverThrowError<T, E> class interface

Constructors

NeverThrowError()

Properties

data ↔ ({E? error, String type, T? value})
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack ↔ StackTrace?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited